@@ -39,21 +39,19 @@ from typing import List
 from dimp import ReliableMessage
 from dimp import Content, ForwardContent
 
-from .content import ContentProcessor
+from .base import BaseContentProcessor
 
 
 #
 #   Forward Content Processor
 #
-class ForwardContentProcessor(ContentProcessor):
+class ForwardContentProcessor(BaseContentProcessor):
 
     # Override
     def process(self, content: Content, msg: ReliableMessage) -> List[Content]:
         assert isinstance(content, ForwardContent), 'forward content error: %s' % content
         # call messenger to process it
         messenger = self.messenger
-        # from ..messenger import Messenger
-        # assert isinstance(messenger, Messenger)
         secret = content.message
         # 1. verify message
         s_msg = messenger.verify_message(msg=secret)
