@@ -39,12 +39,12 @@ from typing import List
 from dimp import ID, Meta
 from dimp import ReliableMessage
 from dimp import Content
-from dimp import Command, MetaCommand
+from dimp import MetaCommand
 
-from .command import CommandProcessor
+from .base import BaseCommandProcessor
 
 
-class MetaCommandProcessor(CommandProcessor):
+class MetaCommandProcessor(BaseCommandProcessor):
 
     STR_META_CMD_ERROR = 'Meta command error'
     FMT_META_NOT_FOUND = 'Sorry, meta not found for ID: %s'
@@ -52,10 +52,7 @@ class MetaCommandProcessor(CommandProcessor):
     FMT_META_ACCEPTED = 'Meta received: %s'
 
     def __get_meta(self, identifier: ID) -> List[Content]:
-        facebook = self.facebook
-        # from dimp import Barrack
-        # assert isinstance(facebook, Barrack)
-        meta = facebook.meta(identifier=identifier)
+        meta = self.facebook.meta(identifier=identifier)
         if meta is None:
             text = self.FMT_META_NOT_FOUND % identifier
             return self._respond_text(text=text)
@@ -64,10 +61,7 @@ class MetaCommandProcessor(CommandProcessor):
             return [res]
 
     def __put_meta(self, identifier: ID, meta: Meta) -> List[Content]:
-        facebook = self.facebook
-        # from ..facebook import Facebook
-        # assert isinstance(facebook, Facebook)
-        if not facebook.save_meta(meta=meta, identifier=identifier):
+        if not self.facebook.save_meta(meta=meta, identifier=identifier):
             text = self.FMT_META_NOT_ACCEPTED % identifier
             return self._respond_text(text=text)
         else:
@@ -75,10 +69,10 @@ class MetaCommandProcessor(CommandProcessor):
             return self._respond_receipt(text=text)
 
     # Override
-    def execute(self, cmd: Command, msg: ReliableMessage) -> List[Content]:
-        assert isinstance(cmd, MetaCommand), 'command error: %s' % cmd
-        identifier = cmd.identifier
-        meta = cmd.meta
+    def process(self, content: Content, msg: ReliableMessage) -> List[Content]:
+        assert isinstance(content, MetaCommand), 'meta command error: %s' % content
+        identifier = content.identifier
+        meta = content.meta
         if identifier is None:
             # error
             return self._respond_text(text=self.STR_META_CMD_ERROR)
