@@ -44,10 +44,9 @@ from dimp import InstantMessage, SecureMessage, ReliableMessage
 from dimp import Transceiver, Packer, Processor
 
 from .delegate import CipherKeyDelegate
-from .transmitter import Transmitter
 
 
-class Messenger(Transceiver, CipherKeyDelegate, Packer, Processor, Transmitter):
+class Messenger(Transceiver, CipherKeyDelegate, Packer, Processor):
 
     @property
     def key_cache(self) -> CipherKeyDelegate:
@@ -64,11 +63,6 @@ class Messenger(Transceiver, CipherKeyDelegate, Packer, Processor, Transmitter):
         """ Delegate for Processing Message """
         raise NotImplemented
 
-    @property
-    def transmitter(self) -> Transmitter:
-        """ Delegate for Transmitting Message """
-        raise NotImplemented
-
     #
     #   Interfaces for Cipher Key
     #
@@ -151,25 +145,6 @@ class Messenger(Transceiver, CipherKeyDelegate, Packer, Processor, Transmitter):
         delegate = self.processor
         return delegate.process_content(content=content, r_msg=r_msg)
 
-    #
-    #   Interfaces for Transmitting Message
-    #
-
-    # Override
-    def send_content(self, sender: Optional[ID], receiver: ID, content: Content, priority: int) -> bool:
-        delegate = self.transmitter
-        return delegate.send_content(sender=sender, receiver=receiver, content=content, priority=priority)
-
-    # Override
-    def send_instant_message(self, msg: InstantMessage, priority: int) -> bool:
-        delegate = self.transmitter
-        return delegate.send_instant_message(msg=msg, priority=priority)
-
-    # Override
-    def send_reliable_message(self, msg: ReliableMessage, priority: int) -> bool:
-        delegate = self.transmitter
-        return delegate.send_reliable_message(msg=msg, priority=priority)
-
     #
     #   SecureMessageDelegate
     #
