@@ -35,10 +35,14 @@
 """
 
 from .coder import *
-from .rsa import RSAPublicKey, RSAPrivateKey
-from .aes import AESKey
-from .plain import PlainKey
+from .digest import *
+from .factories import *
+
 
 __all__ = [
+
     'PlainKey',
+
+    'BTCAddress', 'ETHAddress',
+    'DefaultMeta', 'BTCMeta', 'ETHMeta',
 ]
